Module accounts

Module accounts 

An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.

Structs

ConfigInit
Generated client accounts for ConfigInit.
ConfigUpdate
Generated client accounts for ConfigUpdate.
FiberClose
Generated client accounts for FiberClose.
FiberCreate
Generated client accounts for FiberCreate.
FiberSwap
Generated client accounts for FiberSwap.
FiberUpdate
Generated client accounts for FiberUpdate.
ThreadClose
Generated client accounts for ThreadClose.
ThreadCreate
Generated client accounts for ThreadCreate.
ThreadDelete
Generated client accounts for ThreadDelete.
ThreadExec
Generated client accounts for ThreadExec.
ThreadMemo
Generated client accounts for ThreadMemo.
ThreadUpdate
Generated client accounts for ThreadUpdate.
ThreadWithdraw
Generated client accounts for ThreadWithdraw.