pub struct FiberClose {
pub authority: Pubkey,
pub close_to: Pubkey,
pub thread: Pubkey,
pub fiber: Option<Pubkey>,
}Expand description
Generated client accounts for FiberClose.
Fields
The authority of the thread or the thread itself
close_to: PubkeyThe address to return the data rent lamports to
thread: PubkeyThe thread to remove the fiber from
fiber: Option<Pubkey>The fiber account to close (optional - not needed if closing inline fiber)