pub struct FiberUpdate {
pub authority: Pubkey,
pub thread: Pubkey,
pub fiber: Pubkey,
pub fiber_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for FiberUpdate.
Fields
The authority of the thread or the thread itself
thread: PubkeyThe thread the fiber belongs to
fiber: Pubkeyfiber_program: PubkeyThe Fiber Program for CPI
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for FiberUpdate
impl BorshSerialize for FiberUpdate
Sourceimpl ToAccountMetas for FiberUpdate
impl ToAccountMetas for FiberUpdate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for FiberUpdate
impl RefUnwindSafe for FiberUpdate
impl Send for FiberUpdate
impl Sync for FiberUpdate
impl Unpin for FiberUpdate
impl UnsafeUnpin for FiberUpdate
impl UnwindSafe for FiberUpdate