pub struct ThreadCreate {
pub authority: Pubkey,
pub payer: Pubkey,
pub thread: Pubkey,
pub nonce_account: Option<Pubkey>,
pub recent_blockhashes: Option<Pubkey>,
pub rent: Option<Pubkey>,
pub system_program: Pubkey,
}Expand description
Generated client accounts for ThreadCreate.
Fields
payer: PubkeyThe payer for account initializations.
thread: PubkeyThe thread to be created.
nonce_account: Option<Pubkey>When provided, recent_blockhashes and rent must also be provided.
recent_blockhashes: Option<Pubkey>rent: Option<Pubkey>system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ThreadCreate
impl BorshSerialize for ThreadCreate
Sourceimpl ToAccountMetas for ThreadCreate
impl ToAccountMetas for ThreadCreate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.