pub struct ThreadDelete {
pub admin: Pubkey,
pub config: Pubkey,
pub thread: Pubkey,
}Expand description
Generated client accounts for ThreadDelete.
Fields
admin: PubkeyThe config admin (must sign)
config: PubkeyThe config account
thread: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ThreadDelete
impl BorshSerialize for ThreadDelete
Sourceimpl ToAccountMetas for ThreadDelete
impl ToAccountMetas for ThreadDelete
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ThreadDelete
impl RefUnwindSafe for ThreadDelete
impl Send for ThreadDelete
impl Sync for ThreadDelete
impl Unpin for ThreadDelete
impl UnsafeUnpin for ThreadDelete
impl UnwindSafe for ThreadDelete