pub struct ThreadExec {
pub executor: Pubkey,
pub thread: Pubkey,
pub fiber: Pubkey,
pub config: Pubkey,
pub admin: Pubkey,
pub nonce_account: Option<Pubkey>,
pub recent_blockhashes: Option<Pubkey>,
pub system_program: Pubkey,
}Expand description
Generated client accounts for ThreadExec.
Fields
executor: PubkeyThe executor sending and paying for the transaction
thread: PubkeyThe thread being executed
Note: dup allows thread to appear in remaining_accounts (from compiled instruction)
fiber: PubkeyThe fiber to execute (owned by Fiber Program)
config: PubkeyThe config for fee distribution
admin: Pubkeynonce_account: Option<Pubkey>Optional nonce account for durable nonces
recent_blockhashes: Option<Pubkey>system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ThreadExec
impl BorshSerialize for ThreadExec
Sourceimpl ToAccountMetas for ThreadExec
impl ToAccountMetas for ThreadExec
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ThreadExec
impl RefUnwindSafe for ThreadExec
impl Send for ThreadExec
impl Sync for ThreadExec
impl Unpin for ThreadExec
impl UnsafeUnpin for ThreadExec
impl UnwindSafe for ThreadExec