Module cpi

Module cpi 

Modules

accounts
An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is an AccountInfo. This is useful for CPI.

Structs

Return

Functions

close_fiber
create_fiber
swap_fiber
update_fiber