pub struct CreateThread {
pub amount: u64,
pub id: ThreadId,
pub trigger: Trigger,
pub paused: Option<bool>,
pub instruction: Option<SerializableInstruction>,
pub priority_fee: Option<u64>,
}Expand description
Instruction.
Fields
amount: u64id: ThreadIdtrigger: Triggerpaused: Option<bool>instruction: Option<SerializableInstruction>priority_fee: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for CreateThread
impl BorshDeserialize for CreateThread
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateThread
impl BorshSerialize for CreateThread
Sourceimpl Discriminator for CreateThread
impl Discriminator for CreateThread
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreateThread
impl InstructionData for CreateThread