pub struct ErrorThread {
pub error_code: u32,
pub error_message: String,
}Expand description
Instruction.
Fields
error_code: u32error_message: StringTrait Implementations
Sourceimpl BorshDeserialize for ErrorThread
impl BorshDeserialize for ErrorThread
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ErrorThread
impl BorshSerialize for ErrorThread
Sourceimpl Discriminator for ErrorThread
impl Discriminator for ErrorThread
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for ErrorThread
impl InstructionData for ErrorThread