pub struct ExecThread {
pub forgo_commission: bool,
pub fiber_cursor: u8,
}Expand description
Instruction.
Fields
forgo_commission: boolfiber_cursor: u8Trait Implementations
Sourceimpl BorshDeserialize for ExecThread
impl BorshDeserialize for ExecThread
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ExecThread
impl BorshSerialize for ExecThread
Sourceimpl Discriminator for ExecThread
impl Discriminator for ExecThread
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for ExecThread
impl InstructionData for ExecThread