pub struct UpdateConfig {
pub params: ConfigUpdateParams,
}Expand description
Instruction.
Fields
params: ConfigUpdateParamsTrait Implementations
Sourceimpl BorshDeserialize for UpdateConfigwhere
ConfigUpdateParams: BorshDeserialize,
impl BorshDeserialize for UpdateConfigwhere
ConfigUpdateParams: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateConfigwhere
ConfigUpdateParams: BorshSerialize,
impl BorshSerialize for UpdateConfigwhere
ConfigUpdateParams: BorshSerialize,
Sourceimpl Discriminator for UpdateConfig
impl Discriminator for UpdateConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more