pub struct UpdateFiber {
pub fiber_index: u8,
pub instruction: SerializableInstruction,
pub priority_fee: Option<u64>,
pub track: bool,
}Expand description
Instruction.
Fields
fiber_index: u8instruction: SerializableInstructionpriority_fee: Option<u64>track: boolTrait Implementations
Sourceimpl BorshDeserialize for UpdateFiber
impl BorshDeserialize for UpdateFiber
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateFiber
impl BorshSerialize for UpdateFiber
Sourceimpl Discriminator for UpdateFiber
impl Discriminator for UpdateFiber
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateFiber
impl InstructionData for UpdateFiber