pub struct UpdateThread {
pub params: ThreadUpdateParams,
}Expand description
Instruction.
Fields
params: ThreadUpdateParamsTrait Implementations
Sourceimpl BorshDeserialize for UpdateThread
impl BorshDeserialize for UpdateThread
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateThread
impl BorshSerialize for UpdateThread
Sourceimpl Discriminator for UpdateThread
impl Discriminator for UpdateThread
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateThread
impl InstructionData for UpdateThread