pub struct FiberCreate<'info> {
pub authority: Signer<'info>,
pub thread: Account<'info, Thread>,
pub fiber: UncheckedAccount<'info>,
pub fiber_program: Program<'info, AntegenFiber>,
pub system_program: Program<'info, System>,
}Expand description
Accounts required by the fiber_create instruction.
Validates authority, pre-funds fiber from thread, CPIs to Fiber Program to create,
updates thread fiber tracking.
Fields
The authority of the thread or the thread itself
thread: Account<'info, Thread>The thread to add the fiber to
fiber: UncheckedAccount<'info>CHECK: Initialized by Fiber Program via CPI
fiber_program: Program<'info, AntegenFiber>The Fiber Program for CPI
system_program: Program<'info, System>Trait Implementations
Sourceimpl<'info> Accounts<'info, FiberCreateBumps> for FiberCreate<'info>where
'info: 'info,
impl<'info> Accounts<'info, FiberCreateBumps> for FiberCreate<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut FiberCreateBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut FiberCreateBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl<'info> AccountsExit<'info> for FiberCreate<'info>where
'info: 'info,
impl<'info> AccountsExit<'info> for FiberCreate<'info>where
'info: 'info,
Sourceimpl<'info> Bumps for FiberCreate<'info>where
'info: 'info,
impl<'info> Bumps for FiberCreate<'info>where
'info: 'info,
Sourcetype Bumps = FiberCreateBumps
type Bumps = FiberCreateBumps
Struct to hold account bump seeds.
Sourceimpl<'info> DuplicateMutableAccountKeys for FiberCreate<'info>where
'info: 'info,
impl<'info> DuplicateMutableAccountKeys for FiberCreate<'info>where
'info: 'info,
fn duplicate_mutable_account_keys(&self) -> Vec<Pubkey>
Sourceimpl<'info> ToAccountInfos<'info> for FiberCreate<'info>where
'info: 'info,
impl<'info> ToAccountInfos<'info> for FiberCreate<'info>where
'info: 'info,
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for FiberCreate<'info>
impl<'info> ToAccountMetas for FiberCreate<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> Freeze for FiberCreate<'info>
impl<'info> !RefUnwindSafe for FiberCreate<'info>
impl<'info> !Send for FiberCreate<'info>
impl<'info> !Sync for FiberCreate<'info>
impl<'info> Unpin for FiberCreate<'info>
impl<'info> UnsafeUnpin for FiberCreate<'info>
impl<'info> !UnwindSafe for FiberCreate<'info>