Trigger

Enum Trigger 

pub enum Trigger {
    Account {
        address: Pubkey,
        offset: u64,
        size: u64,
    },
    Immediate {
        jitter: u64,
    },
    Timestamp {
        unix_ts: i64,
        jitter: u64,
    },
    Interval {
        seconds: i64,
        skippable: bool,
        jitter: u64,
    },
    Cron {
        schedule: String,
        skippable: bool,
        jitter: u64,
    },
    Slot {
        slot: u64,
    },
    Epoch {
        epoch: u64,
    },
}
The triggering conditions of a thread.

Variants



Account

Allows a thread to be kicked off whenever the data of an account changes.

Fields

address: Pubkey

The address of the account to monitor.

offset: u64

The byte offset of the account data to monitor.

size: u64

The size of the byte slice to monitor (must be less than 1kb)



Immediate

Allows a thread to be kicked off as soon as it’s created.

Fields

jitter: u64

Optional jitter in seconds to prevent thundering herd (0 = no jitter)



Timestamp

Allows a thread to be kicked off according to a unix timestamp.

Fields

unix_ts: i64
jitter: u64

Optional jitter in seconds to spread execution across a window (0 = no jitter)



Interval

Allows a thread to be kicked off at regular intervals.

Fields

seconds: i64

Interval in seconds between executions

skippable: bool

Boolean value indicating whether triggering moments may be skipped

jitter: u64

Optional jitter in seconds to prevent thundering herd (0 = no jitter)



Cron

Allows a thread to be kicked off according to a one-time or recurring schedule.

Fields

schedule: String

The schedule in cron syntax. Value must be parsable by the antegen_cron package.

skippable: bool

Boolean value indicating whether triggering moments may be skipped if they are missed (e.g. due to network downtime). If false, any “missed” triggering moments will simply be executed as soon as the network comes back online.

jitter: u64

Optional jitter in seconds to spread execution across a window (0 = no jitter)



Slot

Allows a thread to be kicked off according to a slot.

Fields

slot: u64


Epoch

Allows a thread to be kicked off according to an epoch number.

Fields

epoch: u64