pub struct CompiledInstructionData {
pub program_id_index: u8,
pub accounts: Vec<u8>,
pub data: Vec<u8>,
}Expand description
Compiled instruction data for space-efficient storage
Fields
program_id_index: u8accounts: Vec<u8>data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for CompiledInstructionData
impl BorshDeserialize for CompiledInstructionData
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<CompiledInstructionData, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CompiledInstructionData
impl Clone for CompiledInstructionData
Sourcefn clone(&self) -> CompiledInstructionData
fn clone(&self) -> CompiledInstructionData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for CompiledInstructionData
impl RefUnwindSafe for CompiledInstructionData
impl Send for CompiledInstructionData
impl Sync for CompiledInstructionData
impl Unpin for CompiledInstructionData
impl UnsafeUnpin for CompiledInstructionData
impl UnwindSafe for CompiledInstructionData