Struct PaymentDetails
Source pub struct PaymentDetails {
pub fee_payer_reimbursement: u64,
pub executor_commission: u64,
pub core_team_fee: u64,
}
Struct to hold payment details
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.