pub struct SerializableAccountMeta {
pub pubkey: Address,
pub is_signer: bool,
pub is_writable: bool,
}Expand description
Serializable version of AccountMeta
Fields
pubkey: Addressis_signer: boolis_writable: boolTrait Implementations
Sourceimpl BorshDeserialize for SerializableAccountMeta
impl BorshDeserialize for SerializableAccountMeta
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SerializableAccountMeta, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SerializableAccountMeta
impl Clone for SerializableAccountMeta
Sourcefn clone(&self) -> SerializableAccountMeta
fn clone(&self) -> SerializableAccountMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SerializableAccountMeta
impl RefUnwindSafe for SerializableAccountMeta
impl Send for SerializableAccountMeta
impl Sync for SerializableAccountMeta
impl Unpin for SerializableAccountMeta
impl UnsafeUnpin for SerializableAccountMeta
impl UnwindSafe for SerializableAccountMeta