pub struct SerializableInstruction {
pub program_id: Pubkey,
pub accounts: Vec<SerializableAccountMeta>,
pub data: Vec<u8>,
}Expand description
Serializable version of Solana’s Instruction for easier handling
Fields
program_id: Pubkeyaccounts: Vec<SerializableAccountMeta>data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for SerializableInstruction
impl BorshDeserialize for SerializableInstruction
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SerializableInstruction
impl Clone for SerializableInstruction
Sourcefn clone(&self) -> SerializableInstruction
fn clone(&self) -> SerializableInstruction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializableInstruction
impl Debug for SerializableInstruction
Sourceimpl From<Instruction> for SerializableInstruction
impl From<Instruction> for SerializableInstruction
Sourcefn from(ix: Instruction) -> Self
fn from(ix: Instruction) -> Self
Converts to this type from the input type.
Sourceimpl From<SerializableInstruction> for Instruction
impl From<SerializableInstruction> for Instruction
Sourcefn from(ix: SerializableInstruction) -> Self
fn from(ix: SerializableInstruction) -> Self
Converts to this type from the input type.