Module utils

Module utils 

Functions

calculate_jitter_offset
Calculate deterministic jitter offset using prev timestamp and thread pubkey This creates a feedback loop where each execution’s timing affects the next jitter
next_timestamp
Calculate the next timestamp for a cron schedule
transfer_lamports
Safely transfer lamports from one account to another