calculate_jitter_offset

Function calculate_jitter_offset 

pub fn calculate_jitter_offset(
    prev_timestamp: i64,
    thread_pubkey: &Pubkey,
    jitter: u64,
) -> i64
Calculate deterministic jitter offset using prev timestamp and thread pubkey This creates a feedback loop where each execution’s timing affects the next jitter