pub struct FiberCreate {
pub authority: Pubkey,
pub payer: Pubkey,
pub thread: Pubkey,
pub fiber: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for FiberCreate.
Fields
The authority of the thread or the thread itself
payer: PubkeyThe payer for account initializations
thread: PubkeyThe thread to add the fiber to
fiber: PubkeyThe fiber account to create
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for FiberCreatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for FiberCreatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for FiberCreate
impl ToAccountMetas for FiberCreate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.