pub struct ThreadError {
pub executor: Pubkey,
pub thread: Pubkey,
pub config: Pubkey,
pub admin: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for ThreadError.
Fields
executor: PubkeyThe executor reporting the error
thread: PubkeyThe thread that failed to execute
config: PubkeyThe config for calculating reimbursement
admin: PubkeyThe config admin (receives 0 fee but needed for payment distribution)
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ThreadErrorwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ThreadErrorwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ThreadError
impl ToAccountMetas for ThreadError
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.