#[repr(u32)]pub enum AntegenThreadError {
Show 43 variants
InvalidThreadResponse = 0,
InvalidThreadState = 1,
InvalidTriggerVariant = 2,
InvalidNonceAccount = 3,
TriggerConditionFailed = 4,
ThreadBusy = 5,
ThreadPaused = 6,
RateLimitExeceeded = 7,
MaxRateLimitExceeded = 8,
UnauthorizedWrite = 9,
WithdrawalTooLarge = 10,
ThreadIdTooLong = 11,
InsufficientFunds = 12,
MathOverflow = 13,
ThreadHasNoNonceAccount = 14,
ThreadBeingObserved = 15,
ObserverNotClaimed = 16,
InvalidThreadAuthority = 17,
InvalidObserverAuthority = 18,
InvalidRegistryAdmin = 19,
InvalidInstruction = 20,
InvalidSignatory = 21,
MustBeCalledViaCPI = 22,
AlreadyClaimed = 23,
WrongFiberIndex = 24,
ObserverPriorityActive = 25,
TriggerNotReady = 26,
NonceRequired = 27,
InvalidObserverAccount = 28,
InvalidConfigAdmin = 29,
GlobalPauseActive = 30,
InvalidAuthority = 31,
InvalidFeePercentage = 32,
MissingFiberAccount = 33,
InvalidFiberIndex = 34,
ThreadHasFibers = 35,
ThreadHasNoFibersToExecute = 36,
InvalidExecIndex = 37,
FiberAccountRequired = 38,
InvalidFiberCursor = 39,
InvalidFiberAccount = 40,
MissingFiberAccounts = 41,
CloseNotSignaled = 42,
}Expand description
Errors for the the Antegen thread program.
Variants
InvalidThreadResponse = 0
Thrown if a exec response has an invalid program ID or cannot be parsed.
InvalidThreadState = 1
Thrown if a thread has an invalid state and cannot complete the operation.
InvalidTriggerVariant = 2
The provided trigger variant is invalid.
InvalidNonceAccount = 3
The provided nonce account is invalid.
TriggerConditionFailed = 4
Thrown if a exec instruction is invalid because the thread’s trigger condition has not been met.
ThreadBusy = 5
ThreadPaused = 6
Thrown if a request is invalid because the thread is currently paused.
RateLimitExeceeded = 7
Thrown if a exec instruction would cause a thread to exceed its rate limit.
MaxRateLimitExceeded = 8
Thrown if a thread authority attempts to set a rate limit above the maximum allowed value.
Thrown if an inner instruction attempted to write to an unauthorized address.
WithdrawalTooLarge = 10
Thrown if the user attempts to withdraw SOL that would put a thread below it’s minimum rent threshold.
ThreadIdTooLong = 11
InsufficientFunds = 12
MathOverflow = 13
ThreadHasNoNonceAccount = 14
ThreadBeingObserved = 15
ObserverNotClaimed = 16
InvalidThreadAuthority = 17
InvalidObserverAuthority = 18
InvalidRegistryAdmin = 19
InvalidInstruction = 20
InvalidSignatory = 21
MustBeCalledViaCPI = 22
AlreadyClaimed = 23
WrongFiberIndex = 24
ObserverPriorityActive = 25
TriggerNotReady = 26
NonceRequired = 27
InvalidObserverAccount = 28
InvalidConfigAdmin = 29
GlobalPauseActive = 30
InvalidAuthority = 31
InvalidFeePercentage = 32
MissingFiberAccount = 33
InvalidFiberIndex = 34
ThreadHasFibers = 35
ThreadHasNoFibersToExecute = 36
InvalidExecIndex = 37
FiberAccountRequired = 38
InvalidFiberCursor = 39
InvalidFiberAccount = 40
MissingFiberAccounts = 41
CloseNotSignaled = 42
Implementations