An Anchor generated module containing the program’s set of
instructions, where each method handler in the #[program] mod is
associated with a struct defining the input arguments to the
method. These should be used directly, when one wants to serialize
Anchor instruction data, for example, when specifying
instructions on a client.
Structs
- Close
Fiber - Instruction.
- Close
Thread - Instruction.
- Create
Fiber - Instruction.
- Create
Thread - Instruction.
- Delete
Thread - Instruction.
- Exec
Thread - Instruction.
- Init
Config - Instruction.
- Swap
Fiber - Instruction.
- Thread
Memo - Instruction.
- Update
Config - Instruction.
- Update
Fiber - Instruction.
- Update
Thread - Instruction.
- Withdraw
Thread - Instruction.