Module instruction

Module instruction 

An Anchor generated module containing the program’s set of instructions, where each method handler in the #[program] mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when specifying instructions on a client.

Structs

CreateFiber
Instruction.
CreateThread
Instruction.
DeleteFiber
Instruction.
DeleteThread
Instruction.
ErrorThread
Instruction.
ExecThread
Instruction.
ForceDeleteThread
Instruction.
InitConfig
Instruction.
ThreadMemo
Instruction.
ToggleThread
Instruction.
UpdateConfig
Instruction.
UpdateFiber
Instruction.
UpdateThread
Instruction.
WithdrawThread
Instruction.