pub struct WithdrawThread {
pub amount: u64,
}Expand description
Instruction.
Fields
amount: u64Trait Implementations
Sourceimpl BorshDeserialize for WithdrawThread
impl BorshDeserialize for WithdrawThread
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for WithdrawThread
impl BorshSerialize for WithdrawThread
Sourceimpl Discriminator for WithdrawThread
impl Discriminator for WithdrawThread
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more