pub enum Trigger {
Account {
address: Pubkey,
offset: u64,
size: u64,
},
Immediate {
jitter: u64,
},
Timestamp {
unix_ts: i64,
jitter: u64,
},
Interval {
seconds: i64,
skippable: bool,
jitter: u64,
},
Cron {
schedule: String,
skippable: bool,
jitter: u64,
},
Slot {
slot: u64,
},
Epoch {
epoch: u64,
},
}Expand description
The triggering conditions of a thread.
Variants
Account
Allows a thread to be kicked off whenever the data of an account changes.
Fields
Immediate
Allows a thread to be kicked off as soon as it’s created.
Timestamp
Allows a thread to be kicked off according to a unix timestamp.
Fields
Interval
Allows a thread to be kicked off at regular intervals.
Fields
Cron
Allows a thread to be kicked off according to a one-time or recurring schedule.
Fields
Slot
Allows a thread to be kicked off according to a slot.
Epoch
Allows a thread to be kicked off according to an epoch number.