pub struct CompiledInstructionV0 {
pub num_ro_signers: u8,
pub num_rw_signers: u8,
pub num_rw: u8,
pub instructions: Vec<CompiledInstructionData>,
pub signer_seeds: Vec<Vec<Vec<u8>>>,
pub accounts: Vec<Pubkey>,
}Expand description
Compiled instruction containing deduplicated accounts
Fields
num_ro_signers: u8num_rw_signers: u8num_rw: u8instructions: Vec<CompiledInstructionData>signer_seeds: Vec<Vec<Vec<u8>>>accounts: Vec<Pubkey>Trait Implementations
Sourceimpl BorshDeserialize for CompiledInstructionV0
impl BorshDeserialize for CompiledInstructionV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CompiledInstructionV0
impl Clone for CompiledInstructionV0
Sourcefn clone(&self) -> CompiledInstructionV0
fn clone(&self) -> CompiledInstructionV0
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for CompiledInstructionV0
impl RefUnwindSafe for CompiledInstructionV0
impl Send for CompiledInstructionV0
impl Sync for CompiledInstructionV0
impl Unpin for CompiledInstructionV0
impl UnwindSafe for CompiledInstructionV0